@@ -7,7 +7,7 @@
  *
  * See the enclosed file COPYING for license information.
  *
- * $Horde: kronolith/lib/FBView/day.php,v 1.13.4.3 2005/08/15 23:42:54 jan Exp $
+ * $Horde: kronolith/lib/FBView/day.php,v 1.13.4.3.2.1 2005/12/06 00:12:04 jan Exp $
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
  * @author  Jan Schneider <jan@horde.org>
@@ -61,7 +61,7 @@ class Kronolith_FreeBusy_View_day extends Kronolith_FreeBusy_View {
 
         $template->set('top', $count++ * 15);
         $template->set('columns', range($this->_startHour, $this->_endHour - 1));
-        $template->set('width', 100 / ($this->_endHour - $this->_startHour));
+        $template->set('width', round(100 / ($this->_endHour - $this->_startHour)));
         $blocks .= $template->fetch(KRONOLITH_TEMPLATES . '/fbview/linesblock.tpl');
 
         return $blocks;
@@ -84,7 +84,7 @@ class Kronolith_FreeBusy_View_day extends Kronolith_FreeBusy_View {
     {
         $twentyFour = $GLOBALS['prefs']->getValue('twentyFour');
         $hours_html = '<table width="100%" cellspacing="0" style="text-align:center; border-collapse:collapse"><tr>';
-        $width = 100 / ($this->_endHour - $this->_startHour + 1);
+        $width = round(100 / ($this->_endHour - $this->_startHour + 1));
         for ($i = $this->_startHour; $i < $this->_endHour; $i++) {
             $hour = date($twentyFour ? 'G:00' : 'g:00a', mktime($i));
             $hours_html .= '<td style="border-left:1px solid black; border-right:1px solid black; width:' .
