@@ -32,7 +32,7 @@ define('KRONOLITH_ERROR_FB_NOT_FOUND', 1);
 /**
  * The Kronolith:: class provides functionality common to all of Kronolith.
  *
- * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.18 2005/08/05 14:33:53 jan Exp $
+ * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.18.2.1 2005/12/05 23:55:35 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Kronolith 0.1
@@ -857,7 +857,7 @@ class Kronolith {
 
         $default_domain = empty($conf['storage']['default_domain']) ? null : $conf['storage']['default_domain'];
         $res = $rfc822->parseAddressList($email, $default_domain);
-        if (is_a('PEAR_Error', $res)) {
+        if (is_a($res, 'PEAR_Error')) {
             return $res;
         }
         if (!count($res)) {
